Enum pretty_exec::clap::ColorChoice
[−]pub enum ColorChoice {
Auto,
Always,
Never,
}Expand description
Represents the color preferences for program output
Variants
Auto
Enables colored output only when the output is going to a terminal or TTY.
NOTE: This is the default behavior of clap.
Platform Specific
This setting only applies to Unix, Linux, and macOS (i.e. non-Windows platforms).
Examples
Command::new("myprog")
.color(ColorChoice::Auto)
.get_matches();Always
Enables colored output regardless of whether or not the output is going to a terminal/TTY.
Platform Specific
This setting only applies to Unix, Linux, and macOS (i.e. non-Windows platforms).
Examples
Command::new("myprog")
.color(ColorChoice::Always)
.get_matches();Never
Disables colored output no matter if the output is going to a terminal/TTY, or not.
Platform Specific
This setting only applies to Unix, Linux, and macOS (i.e. non-Windows platforms)
Examples
Command::new("myprog")
.color(ColorChoice::Never)
.get_matches();Trait Implementations
impl Clone for ColorChoice
impl Clone for ColorChoice
fn clone(&self) -> ColorChoice
fn clone(&self) -> ColorChoice
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
impl Debug for ColorChoice
impl Debug for ColorChoice
impl Default for ColorChoice
impl Default for ColorChoice
fn default() -> ColorChoice
fn default() -> ColorChoice
Returns the “default value” for a type. Read more
impl PartialEq<ColorChoice> for ColorChoice
impl PartialEq<ColorChoice> for ColorChoice
impl Copy for ColorChoice
impl Eq for ColorChoice
impl StructuralEq for ColorChoice
impl StructuralPartialEq for ColorChoice