Module pretty_exec::log::syntax_highlight
source · [−]Modules
This is a library for controlling colors and formatting, such as red bold text or blue underlined text, on ANSI terminals.
This is a library for controlling colors and formatting, such as red bold text or blue underlined text, on ANSI terminals.