pub struct Infix(_, _);
Like AnsiString, but only displays the difference between two styles.

This type implements the Display trait, meaning it can be written to a std::fmt formatting without doing any extra allocation, and written to a string with the .to_string() method. For examples, see Style::infix.